# Points Club - System Architecture

## Overview
The Points Club system follows a traditional PHP/MySQL architecture with a focus on simplicity and compatibility with WHM/cPanel hosting environments. The system is designed to be easily installable and maintainable.

## Architecture Components

### 1. Frontend Layer
- HTML5, CSS3, JavaScript (vanilla JS, no frameworks)
- Responsive design using CSS media queries
- Client-side form validation
- AJAX for dynamic content updates

### 2. Backend Layer
- Plain PHP (no frameworks)
- MVC-inspired structure:
  - Models: Database interaction classes
  - Views: PHP templates with HTML
  - Controllers: PHP scripts handling business logic
- Session management for user authentication
- Security measures (input validation, prepared statements, CSRF protection)

### 3. Database Layer
- MySQL database (named 'pointy_db')
- Tables with 'pc_' prefix
- Key tables:
  - pc_users: User account information
  - pc_pyramids: Pyramid game instances
  - pc_positions: User positions within pyramids
  - pc_transactions: Point purchase and cashout records
  - pc_settings: System configuration

### 4. File Structure
```
/
├── assets/
│   ├── css/
│   ├── js/
│   └── images/
├── src/
│   ├── config/
│   ├── controllers/
│   ├── models/
│   ├── views/
│   └── utils/
├── database/
│   └── install.sql
├── installer/
│   ├── index.php
│   ├── steps/
│   └── assets/
└── index.php
```

### 5. Core System Components

#### Authentication System
- Registration, login, password reset
- Session management
- User profile management

#### Pyramid Game Engine
- Pyramid creation and management
- Position assignment algorithm
- Reward distribution system
- Point management

#### Payment Processing
- Mock payment interface (initial implementation)
- Transaction recording
- Future PayPal integration capability

#### Admin Dashboard
- User management
- Game statistics
- System configuration

### 6. Installation System
- Web-based installer
- Database connection setup
- Schema installation
- Configuration file generation
- Installation verification

## Data Flow

1. **User Registration/Login**:
   User → Authentication Controller → User Model → Database

2. **Point Purchase**:
   User → Payment Controller → Transaction Model → Database
   
3. **Pyramid Position Assignment**:
   Payment Controller → Pyramid Controller → Position Model → Database
   
4. **Pyramid Completion and Reward**:
   Pyramid Controller → Position Model → Transaction Model → Database

5. **User Dashboard**:
   User → Dashboard Controller → Multiple Models → Views

## Security Considerations
- Password hashing using PHP's password_hash()
- Prepared statements for all database queries
- Input validation and sanitization
- CSRF token protection for forms
- Session security (httponly cookies, session regeneration)
- XSS prevention through output escaping
